@@ -21,15 +21,15 @@
 from os.path import join
 from hamster import SHARED_DATA_DIR
 from hamster.defs import VERSION
-import gtk, gnomevfs
+import gtk
 import hamster
 
 
 def on_email(about, mail):
-    gnomevfs.url_show("mailto:%s" % mail)
+    gtk.show_uri(gtk.gdk.Screen(), "mailto:%s" % mail, 0L)
 
 def on_url(about, link):
-    gnomevfs.url_show(link)
+    gtk.show_uri(gtk.gdk.Screen(), link, 0L)
 
 gtk.about_dialog_set_email_hook(on_email)
 gtk.about_dialog_set_url_hook(on_url)
@@ -47,7 +47,8 @@ def show_about(parent):
 
     about.set_authors(["Toms Baugis <toms.baugis@gmail.com>",
                        "Patryk Zawadzki <patrys@pld-linux.org>",
-                       "Peteris Caune <cuu508@gmail.com>"])
+                       "Peteris Caune <cuu508@gmail.com>",
+		       "Juanje Ojeda <jojeda@emergya.es>"])
     about.set_artists(["Kalle Persson <kalle@kallepersson.se>"])
 
     about.set_translator_credits(_("translator-credits"))
@@ -59,8 +60,13 @@ def show_about(parent):
         
     zupa = gtk.gdk.pixbuf_new_from_file(hamster_logo)
     about.set_logo(zupa)
+    
+    def on_destroy():
+        parent.about = None
 
     about.connect("response", lambda self, *args: self.destroy())
+    about.connect("destroy", lambda self, *args: on_destroy())
     about.set_screen(parent.get_screen())
     about.show_all()
+    parent.about = about
 
